@@ -15,7 +15,7 @@ def help():
     print(" torancell.wiki()")
     print(" torancell.weather()")
     print(" torancell.mail(your mailaddress)")
-    print(" torancell.handgen()")
+    print(" list = torancell.handgen()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -479,8 +479,7 @@ def handgen():
         l.sort()
     inthand = list(map(ttt,l))
     hand = list(map(intmahjong,inthand))
-    print(hand)
-
+    return hand
 
 
     
\ No newline at end of file
